/* canAttackInNMoves.h
 */
#ifndef _MOVE_CLASSIFIER_CAN_ATTACK_IN_NMOVES
#define _MOVE_CLASSIFIER_CAN_ATTACK_IN_NMOVES
#include "osl/piece.h"
#include "osl/square.h"

namespace osl
{
  namespace move_classifier
  {
    bool
    canAttackInThreeMoves (Player player,
			   Ptype ptype,
			   Square myPos,
			   Square opKingPos);
  }//move_classifier
}// osl
#endif /* _MOVE_CLASSIFIER_CAN_ATTACK_IN_NMOVES */
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
